pub struct AlignedMemory<const ALIGN: usize> { /* private fields */ }Expand description
Provides u8 slices at a specified alignment
Implementations
Sourceimpl<const ALIGN: usize> AlignedMemory<ALIGN>
impl<const ALIGN: usize> AlignedMemory<ALIGN>
Sourcepub fn from_slice(data: &[u8]) -> Self
pub fn from_slice(data: &[u8]) -> Self
Returns a filled AlignedMemory by copying the given slice
Sourcepub fn with_capacity(max_len: usize) -> Self
pub fn with_capacity(max_len: usize) -> Self
Returns a new empty AlignedMemory with uninitialized preallocated memory
Sourcepub fn with_capacity_zeroed(max_len: usize) -> Self
pub fn with_capacity_zeroed(max_len: usize) -> Self
Returns a new empty AlignedMemory with zero initialized preallocated memory
Sourcepub fn zero_filled(max_len: usize) -> Self
pub fn zero_filled(max_len: usize) -> Self
Returns a new filled AlignedMemory with zero initialized preallocated memory
Sourcepub fn write_index(&self) -> usize
pub fn write_index(&self) -> usize
Get the current write index
Sourcepub fn as_slice_mut(&mut self) -> &mut [u8] ⓘ
pub fn as_slice_mut(&mut self) -> &mut [u8] ⓘ
Get an aligned mutable slice
Sourcepub fn fill_write(&mut self, num: usize, value: u8) -> Result<()>
pub fn fill_write(&mut self, num: usize, value: u8) -> Result<()>
Grows memory with value repeated num times starting at the write_index
Sourcepub unsafe fn write_unchecked<T: Pod>(&mut self, value: T)
pub unsafe fn write_unchecked<T: Pod>(&mut self, value: T)
Write a generic type T into the memory.
Safety
Unsafe since it assumes that there is enough capacity.
Sourcepub unsafe fn write_all_unchecked(&mut self, value: &[u8])
pub unsafe fn write_all_unchecked(&mut self, value: &[u8])
Write a slice of bytes into the memory.
Safety
Unsafe since it assumes that there is enough capacity.